* Generic session options - page and line size, no page breaks;
OPTIONS nonumber nodate nocenter pagesize=MAX linesize=MAX formdlim=' ' spool; 									
* Kill default titles on output, ODS tables in log, turn on graphics; 
TITLE; ODS TRACE OFF; ODS LISTING; ODS GRAPHICS ON;

********************************************************************************
*******             BEGIN DATA MANIPULATION FOR EXAMPLE 10b              *******
*******             CHANGE "filesave" to your directory                  *******
********************************************************************************

* Location for original files for these models  change this path;
%LET filesave= C:\Dropbox\Example Data\Rosy Count Data; 
LIBNAME filesave "&filesave.";

* Otherwise, you can import the SPSS version of file into SAS;
PROC IMPORT DATAFILE="&filesave.\Rosy data.sav" OUT=work.example11 DBMS=SPSS REPLACE; RUN;

* Rename predictors;
DATA work.example11; SET work.example11;
* Remove SPSS value labels; FORMAT _ALL_;
	 IF CTSphysicalperp=0  THEN IPV=0; 
ELSE IF CTSphysicalperp=1  THEN IPV=1; 
     IF NEUTRAL_AGGVERBS=0 THEN Neutral=0; 
ELSE IF NEUTRAL_AGGVERBS>0 THEN Neutral=1;
IF NMISS(ERcond, IPV, Neutral, ANGER_AGGVERBS)>0 THEN DELETE;
Aggr = ANGER_AGGVERBS;
LABEL  IPV= 	"Intimate Partner Violence (0=N,1=Y)"
	   Neutral=	"Aggression during Neutral Condition (0=N,1=Y)"
	   ERcond=  "Condition (1=None, 2=CogR, 3=Supp)"
	   Aggr=	"Aggressive Verbalizations Outcome";
RUN;

* Send data to STATA;
PROC EXPORT DATA=work.example11 OUTFILE="&filesave.\example11.dta" DBMS=STATA REPLACE; RUN;

* Create labels for groups;
PROC FORMAT; 
	VALUE Fercond 1="1_None" 2="2_CogR" 3="3_Supp";
RUN;

* Add format to data;
DATA work.example11; SET work.example11;
	FORMAT ERcond Fercond.; RUN;

********************************************************************************
******                    BEGIN EXAMPLE 11 MODELS						 *******
********************************************************************************

* Open output directory to save results to;
ODS RTF FILE="&filesave.\SAS_Example11_Output.rtf" STYLE=HTMLBlue STARTPAGE=NO;

TITLE "Histogram for Aggressive Verbalizations Outcome";
PROC UNIVARIATE NOPRINT DATA=work.example11; VAR Aggr; HISTOGRAM Aggr; 
RUN; QUIT; TITLE1;

TITLE1 "GLM of Aggressive Verbalizations Outcome";
PROC MIXED DATA=work.example11 NOCLPRINT COVTEST NAMELEN=100 METHOD=ML;
CLASS ERcond;
MODEL Aggr = Neutral IPV ERcond IPV*ERcond / RESIDUAL SOLUTION CHISQ;
* Cell means and simple effects of condition per IPV;
LSMEANS ERcond / AT (Neutral IPV) = (0 0) DIFF=ALL; * Cell means and diffs for IPV=0;
LSMEANS ERcond / AT (Neutral IPV) = (0 1) DIFF=ALL; * Cell means and diffs for IPV=1;
* Simple effects of IPV per condition;
ESTIMATE "No/Yes IPV Difference: No Instruct"   IPV 1 IPV*ERcond  1  0  0;
ESTIMATE "No/Yes IPV Difference: Cog Reapp"	    IPV 1 IPV*ERcond  0  1  0;
ESTIMATE "No/Yes IPV Difference: Suppression"	IPV 1 IPV*ERcond  0  0  1;
* Specific interaction contrasts;
ESTIMATE "No/Yes IPV by None/Cog Interaction"  	      IPV*ERcond -1  1  0; 
ESTIMATE "No/Yes IPV by None/Sup Interaction" 	      IPV*ERcond -1  0  1;
ESTIMATE "No/Yes IPV by Cog/Sup  Interaction"  	      IPV*ERcond  0 -1  1;  
RUN; TITLE1;

TITLE1 "Poisson Model of Aggressive Verbalizations";
PROC GLIMMIX DATA=work.example11 NOCLPRINT NAMELEN=100;
CLASS ERcond; 
MODEL Aggr = Neutral IPV ERcond IPV*ERcond / CHISQ SOLUTION LINK=LOG DIST=POISSON;
* Cell means and simple effects of condition per IPV;
LSMEANS ERcond / ILINK AT (Neutral IPV) = (0 0) DIFF=ALL; * Cell means and diffs for IPV=0;
LSMEANS ERcond / ILINK AT (Neutral IPV) = (0 1) DIFF=ALL; * Cell means and diffs for IPV=1;
* Simple effects of IPV per condition;
ESTIMATE "No/Yes IPV Difference: No Instruct"   IPV 1 IPV*ERcond  1  0  0;
ESTIMATE "No/Yes IPV Difference: Cog Reapp"	    IPV 1 IPV*ERcond  0  1  0;
ESTIMATE "No/Yes IPV Difference: Suppression"	IPV 1 IPV*ERcond  0  0  1;
* Specific interaction contrasts;
ESTIMATE "No/Yes IPV by None/Cog Interaction"  	      IPV*ERcond -1  1  0; 
ESTIMATE "No/Yes IPV by None/Sup Interaction" 	      IPV*ERcond -1  0  1;
ESTIMATE "No/Yes IPV by Cog/Sup  Interaction"  	      IPV*ERcond  0 -1  1;     
RUN; TITLE1;

TITLE1 "Negative Binomial Model of Aggressive Verbalizations";
PROC GLIMMIX DATA=work.example11 NOCLPRINT NAMELEN=100;
CLASS ERcond;
MODEL Aggr = Neutral IPV ERcond IPV*ERcond / CHISQ SOLUTION LINK=LOG DIST=NEGBIN;
* Cell means and simple effects of condition per IPV;
LSMEANS ERcond / ILINK AT (Neutral IPV) = (0 0) DIFF=ALL; * Cell means and diffs for IPV=0;
LSMEANS ERcond / ILINK AT (Neutral IPV) = (0 1) DIFF=ALL; * Cell means and diffs for IPV=1;
* Simple effects of IPV per condition;
ESTIMATE "No/Yes IPV Difference: No Instruct"   IPV 1 IPV*ERcond  1  0  0;
ESTIMATE "No/Yes IPV Difference: Cog Reapp"	    IPV 1 IPV*ERcond  0  1  0;
ESTIMATE "No/Yes IPV Difference: Suppression"	IPV 1 IPV*ERcond  0  0  1;
* Specific interaction contrasts;
ESTIMATE "No/Yes IPV by None/Cog Interaction"  	      IPV*ERcond -1  1  0; 
ESTIMATE "No/Yes IPV by None/Sup Interaction" 	      IPV*ERcond -1  0  1;
ESTIMATE "No/Yes IPV by Cog/Sup  Interaction"  	      IPV*ERcond  0 -1  1;   
RUN; TITLE1;

TITLE1 "Zero-Inflated Poisson Model of Aggressive Verbalizations";
PROC GENMOD DATA=work.example11 NAMELEN=100;
CLASS ERcond; 
MODEL Aggr = Neutral IPV ERcond IPV*ERcond / LINK=LOG DIST=ZIP;
ZEROMODEL / LINK=LOGIT; 
RUN; TITLE1;

TITLE1 "Zero-Inflated Negative Binomial Model of Aggressive Verbalizations";
PROC GENMOD DATA=work.example11 NAMELEN=100;
CLASS ERcond; 
MODEL Aggr = Neutral IPV ERcond IPV*ERcond / LINK=LOG DIST=ZINB;
ZEROMODEL / LINK=LOGIT; 
RUN; TITLE1;

* Close word file;
ODS RTF CLOSE;
