* Prevent "more" messages from appearing
set more off, permanently
* Control line length
set linesize 150

********************************************************************************
*******             BEGIN DATA MANIPULATION FOR EXAMPLE 11               *******
*******             CHANGE "filesave" to your directory                  *******
********************************************************************************

* Defining global variable for file location to be replaced in code below
global filesave "C:\Dropbox\Example Data\Rosy Count Data"
 
* Import data, transform variables, apply value formats
use "$filesave\example11.dta", clear
label define fercond 1 "1_None" 2 "2_CogR" 3 "3_Supp"
label values ercond fercond

********************************************************************************
******                    BEGIN EXAMPLE 11 MODELS						                  *******
********************************************************************************

* Save results to separate file
log using $filesave\STATA_Example11_Output.log, replace name(STATA_Example11)
 
display as result "Histogram for Aggressive Verbalizations Outcome"
hist aggr 

display as result "GLM of Aggressive Verbalizations Outcome"
mixed aggr c.neutral c.ipv##ib(last).ercond , mle 
estat ic, n(225),
* Cell means and simple effects of condition per IPV
margins i.ercond, at(c.neutral=0 c.ipv=0) // cell means for IPV=0
margins i.ercond, at(c.neutral=0 c.ipv=0) pwcompare(pveffects) // cell mean diffs
margins i.ercond, at(c.neutral=0 c.ipv=1) // cell means for IPV=1
margins i.ercond, at(c.neutral=0 c.ipv=1) pwcompare(pveffects) // cell mean diffs
* Simple effects of IPV per condition 
lincom c.ipv + c.ipv#i1.ercond  // No/Yes IPV Difference: No Instruction
lincom c.ipv + c.ipv#i2.ercond  // No/Yes IPV Difference: Cognitive Reappraisal
lincom c.ipv + c.ipv#i3.ercond  // No/Yes IPV Difference: Suppression
* Specific interaction contrasts
contrast  c.ipv#i.ercond,           // multivariate test of interaction
contrast {c.ipv#i.ercond -1  1  0}, pveffects // No/Yes IPV by None/Cog Interaction
contrast {c.ipv#i.ercond -1  0  1}, pveffects // No/Yes IPV by None/Sup Interaction
contrast {c.ipv#i.ercond  0 -1  1}, pveffects // No/Yes IPV by Cog/Sup Interaction

display as result "Poisson Model of Aggressive Verbalizations Outcome"
mepoisson aggr c.neutral c.ipv##ib(last).ercond ,
estat ic, n(225),
* Cell means in log count (model version) and simple effects of condition per IPV
margins i.ercond, at(c.neutral=0 c.ipv=0) predict(xb) // cell means for IPV=0
margins i.ercond, at(c.neutral=0 c.ipv=0) predict(xb) pwcompare(pveffects) // cell mean diffs
margins i.ercond, at(c.neutral=0 c.ipv=1) predict(xb) // cell means for IPV=1
margins i.ercond, at(c.neutral=0 c.ipv=1) predict(xb) pwcompare(pveffects) // cell mean diffs
* Cell means in predicted count
margins i.ercond, at(c.neutral=0 c.ipv=0) // cell means for IPV=0
margins i.ercond, at(c.neutral=0 c.ipv=1) // cell means for IPV=1
* Simple effects of IPV per condition  (in log count)
lincom c.ipv + c.ipv#i1.ercond  // No/Yes IPV Difference: No Instruction
lincom c.ipv + c.ipv#i2.ercond  // No/Yes IPV Difference: Cognitive Reappraisal
lincom c.ipv + c.ipv#i3.ercond  // No/Yes IPV Difference: Suppression
* Specific interaction contrasts (in log count)
contrast  c.ipv#i.ercond,           // multivariate test of interaction
contrast {c.ipv#i.ercond -1  1  0}, pveffects // No/Yes IPV by None/Cog Interaction
contrast {c.ipv#i.ercond -1  0  1}, pveffects // No/Yes IPV by None/Sup Interaction
contrast {c.ipv#i.ercond  0 -1  1}, pveffects // No/Yes IPV by Cog/Sup Interaction

display as result "Negative Binomial Model of Aggressive Verbalizations Outcome"
menbreg aggr c.neutral c.ipv##ib(last).ercond ,
estat ic, n(225),
* Cell means in log count (model version) and simple effects of condition per IPV
margins i.ercond, at(c.neutral=0 c.ipv=0) predict(xb) // cell means for IPV=0
margins i.ercond, at(c.neutral=0 c.ipv=0) predict(xb) pwcompare(pveffects) // cell mean diffs
margins i.ercond, at(c.neutral=0 c.ipv=1) predict(xb) // cell means for IPV=1
margins i.ercond, at(c.neutral=0 c.ipv=1) predict(xb) pwcompare(pveffects) // cell mean diffs
* Cell means in predicted count
margins i.ercond, at(c.neutral=0 c.ipv=0) // cell means for IPV=0
margins i.ercond, at(c.neutral=0 c.ipv=1) // cell means for IPV=1
* Simple effects of IPV per condition (in log count)
lincom c.ipv + c.ipv#i1.ercond  // No/Yes IPV Difference: No Instruction
lincom c.ipv + c.ipv#i2.ercond  // No/Yes IPV Difference: Cognitive Reappraisal
lincom c.ipv + c.ipv#i3.ercond  // No/Yes IPV Difference: Suppression
* Specific interaction contrasts (in log count)
contrast  c.ipv#i.ercond,           // multivariate test of interaction
contrast {c.ipv#i.ercond -1  1  0}, pveffects // No/Yes IPV by None/Cog Interaction
contrast {c.ipv#i.ercond -1  0  1}, pveffects // No/Yes IPV by None/Sup Interaction
contrast {c.ipv#i.ercond  0 -1  1}, pveffects // No/Yes IPV by Cog/Sup Interaction
 
display as result "Zero-Inflated Poisson Model of Aggressive Verbalizations Outcome"
display as result "Have to switch to single-level (univariate) model"
zip aggr c.neutral c.ipv##ib(last).ercond , inflate(_cons),
estat ic, n(225),
	
*** STATA BLEW UP!!
*display as result "Zero-Inflated Negative Binomial of Aggressive Verbalizations Outcome"
*display as result "Have to switch to single-level (univariate) model"
*zinb aggr c.neutral c.ipv##ib(last).ercond , inflate(_cons),
*estat ic, n(225),

* Close log	
log close STATA_Example11
